asr.test.test\_projected\_bandstructure
=======================================

.. automodule:: asr.test.test_projected_bandstructure

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_projected_bs_mocked
   
   

   
   
   

   
   
   